/**
 * core.js - all global scripts belong in this file.
 */

utils.currentPage = function() {"use strict"
  let curPage = window.location.pathname.substring(
    window.location.pathname.lastIndexOf ('/') + 1
    ).split("?")[0];
  if(!curPage){ curPage = "home" }
  return curPage
};
utils.debounce = function (func,time){
  var timer;
  return function(event){
    if(timer) clearTimeout(timer);
    timer = setTimeout(func,time,event);
  };
}
utils.scrollDistance = function() {
  return document.documentElement.scrollTop;
}
utils.offsetHeight = function() {
  return document.querySelector('#header').offsetHeight;
}

var instafeed = {
  init: function() {"use strict";
    document.querySelector("#feed").innerHTML = '<!-- LightWidget WIDGET --><script src="https://cdn.lightwidget.com/widgets/lightwidget.js"></script><iframe src="https://cdn.lightwidget.com/widgets/a1b2582b32265d1f8402721b651fdeff.html" scrolling="no" allowtransparency="true" class="lightwidget-widget" style="width:100%;border:0;overflow:hidden;"></iframe>';
  }
};

var optin = {};
optin.forms = document.querySelectorAll('.subscribe');
optin.fields = ["email"]
optin.initializeForms = function() { "use strict";
  function sendAddress(form) {
    var formData = new FormData(form);
    formData.append('ajax', true);

    var xhr = new XMLHttpRequest();
    xhr.open('POST', './_inc/optin_action.php', true);
    xhr.onload = function() {
      if (xhr.status >= 200 && xhr.status < 400) {

        //console.log(xhr.status);
        let response = JSON.parse('[' + xhr.response + ']');
        //console.log(response[0]);
          for(i=0;i<optin.forms.length;i++){
            optin.forms[i].style.display = 'none';
            var parentDiv = optin.forms[i].parentElement;
            if(parentDiv.querySelector('h3:first-child')){
              let thisH3 = parentDiv.querySelector('h3:first-child')
              thisH3.remove();
            }
            var thanksMessage = document.createElement('h3');
            thanksMessage.className = 'text-center form-thanks';
            if (response[0].status == 200){
              thanksMessage.innerHTML = 'THANK YOU FOR <br class="visible-xs" />SIGNING&nbsp;UP.</span>';
            } else if( response[0].status == 400 ) {
            } else {
              if(response[0].detail){
                thanksMessage.innerHTML = response[0].detail;
              } else {
                thanksMessage.innerHTML = "You've been added to&nbsp;the&nbsp;list. Thanks&nbsp;for&nbsp;your subscription.";
              }
            }
            parentDiv.appendChild(thanksMessage);
          }
          dataLayer.push({ 'event': 'signup-successful' });
          optin.submittedSuccessfully = true;
      }
    };
    xhr.send(formData);
  }
  class FormValidator {
    constructor(form, fields) {
      this.form = form
      this.fields = fields
    }
    initialize() {
      this.validateOnSubmit()
    }
    validateOnSubmit() {
      let self = this
      var first_submit = true;
      this.form.addEventListener('submit', e => {
        e.preventDefault()
        self.fields.forEach(field => {
          const inputSelector = "#"+self.form.id+"-"+field;
          const input = document.querySelector(inputSelector)
          self.validateFields(input,true)
          if( first_submit ) {
            self.validateOnEntry()
            first_submit = false;
          }
        })
      })
    }
    validateOnEntry() {
      let self = this
      this.fields.forEach(field => {
        const inputSelector = "#"+self.form.id+"-"+field;
        const input = document.querySelector(inputSelector)
        input.addEventListener('input', event => {
          self.validateFields(input,false)
        })
      })
    }
    validateFields(field,isSubmit) {
      // Check presence of values
      if (field.value.trim() === "") {
        this.setStatus(field, field.id+" cannot be blank", "error")
      } else {
        this.setStatus(field, null, "success")
      }
      let handled = false;
      // check for a valid email address
      if (field.type === "email") {
        const re = /\S+@\S+\.\S+/
        if (re.test(field.value)) {
          this.setStatus(field, null, "success")
          if(isSubmit && !handled){
            sendAddress(this.form);
            handled = true;
          }
        } else {
          this.setStatus(field, "Please enter valid email address", "error")
        }
      }
    }
    setStatus(field, message, status) {
      let thisField = field.parentElement;
      let thisErr = thisField.querySelector('.error-message')
      if (status === "success") {
        thisField.classList.remove('error')
        if(thisErr){
          thisErr.innerHTML = '';
        }
      }
      if (status === "error") {
        thisField.classList.add('error')
        if(thisErr){
          thisErr.innerHTML = message;
        }
      }
    }
  }
  for(var i=0;i < optin.forms.length;i++){
    optin.forms[i].id = "form"+i;
    const validator = new FormValidator(optin.forms[i], optin.fields)
    validator.initialize()
    for(var j=0;j < optin.fields.length;j++){
      let thisField = optin.forms[i].querySelector("input");
      thisField.id = "form"+i+"-"+optin.fields[j];
    }
  }
}
optin.upCount = 0;
optin.rightCount = 0;
optin.prevY = 0;
optin.prevX = 0;
optin.exitPopupOpen = false;
optin.exitPopupInitialized = false;
optin.submittedSuccessfully = false;
optin.exitPopup = function(e) {"use strict";
  optin.exitPopupOpen = true;
  document.documentElement.classList.add('exit-popup-open');
  if(!optin.exitPopupinitialized) {
  /*  let thisOptin = document.querySelector('footer .optin');
    var clone = thisOptin.cloneNode(true);
    document.querySelector('#overlay-inner').innerHTML = '<div class="container boxes flex"><div class="box"><button class="close"><svg id="x" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 306.88 306.88"><polygon class="b" points="306.88 45.26 261.63 0 153.44 108.19 45.25 0 0 45.26 108.19 153.44 0 261.62 45.25 306.88 153.44 198.69 261.63 306.88 306.88 261.62 198.7 153.44 306.88 45.26"/></svg></button></div></div>';
    document.querySelector('#overlay-inner .container .box').append(clone);
    optin.forms = document.querySelectorAll('.subscribe');
    optin.forms[1].id = "form1";
    optin.initializeForms(); */
    optin.exitPopupInitialized = true;
    //document.querySelector('.overlay .optin input[name="email"]').placeholder='Enter your email';
  }
};

// NAMESPACE FOR MAIN MENU FUNCTIONS
var nav = {}
nav.toggle = function(e) {
    // if menu is open, close it up
    if(document.documentElement.classList.contains('menu-open')){
      // but only if no sub categories
      if(!e.target.classList.contains('top-level') && !e.target.classList.contains('arrow')){
        setTimeout(function(){
          document.documentElement.classList.remove('menu-open');
          document.getElementById("nav-close").id = "nav-open";
          document.getElementById("nav-open").setAttribute('aria-label', 'open main menu');
          document.getElementById("nav-open").setAttribute('aria-expanded', false);
        }, 100);
        return true;
      }
    // if menu is closed, open it
    } else {
      document.documentElement.classList.add('menu-open');
      document.getElementById("nav-open").id = "nav-close";
      document.getElementById("nav-close").setAttribute('aria-label', 'close main menu');
      document.getElementById("nav-close").setAttribute('aria-expanded', true);
      return true;
    }
}

// NAMESPACE FOR CLICK FUNCTIONS
var clickHandler = {}
clickHandler.init = function() {"use strict";
  var el = document.querySelector(utils.currentPage());
  if(el){
    el.scrollIntoView({
      behavior: 'smooth' // smooth scroll
    })
  }
  // click handler
  var handled = false;
  function handleClick(e) {
    if(!handled){
      //console.log(e.target);
      handled = true;
      setTimeout(function(){ handled=false },200);
      // main menu
      if( e.target.classList.contains('nav-toggle') || e.target.id == 'main-menu' ){
        nav.toggle(e);
      }
      // video thumbnail
      if(e.target.classList.contains('custom-thumb')){
        video.play('#video-play');
      }
      // overlay close
      if(e.target.classList.contains('close')){
        document.documentElement.classList.remove('exit-popup-open');
        optin.exitPopupOpen = false;
      }
      // listen button
      if(e.target.id == 'btn-listen'){
        spotify.init();
      }
    } else {
      return false;
    }
  }
  window.addEventListener('touchend', handleClick, false);
  window.addEventListener('click', handleClick, false);
};

var scrollHandler = {}
scrollHandler.init = function(){ "use strict"
  var firstScroll = true;
  // handles scroll events for the page
  function handleScroll(e) {
    // first scroll
    if(firstScroll){
      if( document.body.classList.contains('home') ){
        //instafeed.init();
      }
      firstScroll = false;
    }
    // home page
    if(document.body.classList.contains('home')){
      //spotify.showHide();
    }
    // parallax
    if(document.querySelector('.parallax-image')){
      const parallaxImage = document.querySelector('.parallax-image');
      const offsetY = utils.scrollDistance() / 3.7; // Adjust the factor for the parallax effect
      parallaxImage.style.transform = `translate3d(0, ${offsetY}px, 0)`;
    }
    if(document.body.classList.contains('home')){
      if(document.documentElement.classList.contains('touch') && !optin.submittedSuccessfully){
        if(!document.body.classList.contains('touch') && !optin.submittedSuccessfully){
          let scrollDist = utils.scrollDistance();
          //console.log(scrollDist);
          optin.upCount = (scrollDist <= optin.prevSD) ? optin.upCount+1 : 0;
          if((optin.upCount >= 16) && !optin.exitPopupInitialized && !document.documentElement.classList.contains('menu-open')) {
            //optin.exitPopup(e);
          }
          optin.prevSD = scrollDist;
        }
      }
    }
  }
  window.addEventListener("scroll", utils.debounce(function(e){
    handleScroll(e);
  },10));
};

var mouseMoveHandler = {}
mouseMoveHandler.init = function(){ "use strict"
  // handles scroll events for the page
  function handleMouseMove(e) {
    if(!document.documentElement.classList.contains('touch') && !optin.submittedSuccessfully){
      let x = e.clientX;
      let y = e.clientY;
      optin.upCount = (y <= optin.prevY) ? optin.upCount+1 : 0;
      optin.rightCount = (x > optin.prevX) ? optin.rightCount+1 : 0;
      if((optin.upCount >= 12) && (y < 200) && (x > 200) && (x < window.innerWidth - 240) && !optin.exitPopupInitialized && !document.documentElement.classList.contains('menu-open')) {
        //optin.exitPopup(e);
      }
      optin.prevY = y;
      optin.prevX = x;
      //console.log(optin.upCount, optin.rightCount, optin.prevX, optin.prevY);
      //console.log('x='+x+', y='+y);
    }
  }
  window.addEventListener("mousemove", utils.debounce(function(e){
    handleMouseMove(e)
  },7));
};
/*
var popstateHandler = {}
popstateHandler.init = function(){ "use strict"
  // handles scroll events for the page
  function handlePopstate(e) {
    if(!optin.submittedSuccessfully && document.body.classList.contains('touch')){
      optin.exitPopup(e);
    }
  }
  window.addEventListener("popstate", utils.debounce(function(e){
    handlePopstate(e)
  },7));
};*/

// NAMESPACE FOR ROTATOR
var rotator = {};
rotator.rotate = function (selector) { "use strict";
  var thisTimeout;
  var thisSlide = document.querySelector(selector);
  console.log(thisSlide);
  var thisTime = thisSlide.parentElement.dataset.time;
  thisTime = ( thisTime ) ? thisTime : 5000;
  //console.log(thisTime);
  var numberOfSlides = document.querySelectorAll(selector).length;
  var currentSlide = 1;
  var prevSlide = 2;
  var nextSlide = numberOfSlides;
  function rotateSlide() {
    const slides = document.querySelectorAll(selector);
    if( slides ){ slides.forEach((slide) => {
        slide.classList.remove('active', 'next', 'prev', 'current');
      }); }
    document.querySelector(selector + ":nth-child("+currentSlide+")").classList.add('active', 'current');
    currentSlide++;
    if( currentSlide > numberOfSlides ){ currentSlide = 1; }
    if (thisSlide.parentElement.classList.contains("slide")){
      document.querySelector(selector + ":nth-child("+prevSlide+")").classList.add('active', 'prev');
      document.querySelector(selector + ":nth-child("+nextSlide+")").classList.add('active', 'next');
      prevSlide++; nextSlide++;
      if( prevSlide > numberOfSlides ){ prevSlide = 1; }
      if( nextSlide > numberOfSlides ){ nextSlide = 1; }
    }
    if(thisTimeout){clearTimeout(thisTimeout);}
    thisTimeout = setTimeout( rotateSlide, thisTime );
  }
  rotateSlide();
};

var video = {}
video.play = function(videoSelector) {
  let thisVideo = document.querySelector(videoSelector);
  thisVideo.classList.remove('custom-thumb');
  thisVideo.innerHTML = '<iframe width="560" height="315" src="https://www.youtube.com/embed/'+ thisVideo.dataset.id +'?autoplay=1" frameborder="0" allow="accelerometer; autoplay; encrypted-media; gyroscope; picture-in-picture" allowfullscreen></iframe>';
}
video.init = function(){ "use strict"  
  if( utils.isTouchEnabled ) {
    document.querySelector("#video-play.custom-thumb").click;
  }
};
video.overlay = function() { "use strict";
  $(document).on("click",".video-link",function(e){
    e.preventDefault();
    if( $("#video-overlay-close").length == 0 ){
      $("#video-overlay").append('<a id="video-overlay-close"></a>');
    }
    $("#video-overlay-inner").html('<iframe src="https://www.youtube.com/embed/'+ $(this).data("id") +'?rel=0&modestbranding=1&autohide=1&showinfo=0&autoplay=1" frameborder="0" allow="accelerometer; autoplay; encrypted-media; gyroscope; picture-in-picture" allowfullscreen></iframe>');
    $("html").addClass("video-overlay-open");
  });
  $(document).on("click","#video-overlay-close, #video-overlay",function(e){
    e.preventDefault();
    $("#video-overlay-inner").html('');
    $("html").removeClass("video-overlay-open");
  });
}

var spotify = {}
spotify.init = function(){ "use strict"
  let spotify = document.getElementById('spotify');
  spotify.querySelector('.container').innerHTML = '<iframe style="border-radius:12px" src="https://open.spotify.com/embed/album/22UlcdIxtmapTzhh6koX1o?utm_source=generator" width="100%" height="352" frameBorder="0" allowfullscreen="" allow="autoplay; clipboard-write; encrypted-media; fullscreen; picture-in-picture" loading="lazy"></iframe>';
  if(spotify.classList.contains('open')) {
    spotify.classList.remove('open');
  } else {
    spotify.classList.add('open');
  }
};
spotify.showHide = function () {
  // show and hide listen button
  //console.log(utils.scrollDistance());
  //console.log(utils.offsetHeight());
  //console.log(document.getElementById('title').offsetTop - utils.offsetHeight())
  if( utils.scrollDistance() < eval(document.getElementById('title').offsetTop - utils.offsetHeight()) ){
    document.getElementById("btn-listen").classList.remove("active");
  } else {
    document.getElementById("btn-listen").classList.add("active");
  }
}

window.addEventListener("load", (event) => {
  //console.log("page is fully loaded");
});

// jQuery Namespace
$ (document).ready (function () {"use strict";
  //console.log("document ready");
  $('html').addClass('page-loaded');
  clickHandler.init();
  scrollHandler.init();
  
  if (document.body.classList.contains('home')) {
    mouseMoveHandler.init();
    optin.initializeForms();
    //video.init();
    //spotify.showHide();
  }

/* beginning of auto-initialize for Rotator script
  var rotators = document.querySelectorAll('.rotator');
  for (var i=0; i < rotators.length; i++) {
    //rotators[i].querySelector(':first-child');
    console.log(rotators[i].querySelector(':first-child'));
  }
  */

  if (document.body.classList.contains('home')) {
    //rotator.rotate("#header h2.visible-xs > span");
    rotator.rotate("ul.quotes > .quote");
    rotator.rotate("ul.carousel > li");
  }
});